from ..client import Client


class Ads(Client):

    def delete_ads(self, data):
        self.method = "post"
        self.uri_path = "/sb/v4/ads/delete"
        self.data = data
        return self.execute()

    def update_ads(self, data):
        self.method = "put"
        self.uri_path = "/sb/v4/ads"
        self.data = data
        return self.execute()

    def create_product_collection_ads(self, data):
        self.method = "post"
        self.uri_path = "/sb/v4/ads/productCollection"
        self.data = data
        return self.execute()

    def get_ads_list(self, data):
        self.method = "post"
        self.uri_path = "/sb/v4/ads/list"
        self.data = data
        return self.execute()

    def create_video_ads(self, data):
        self.method = "post"
        self.uri_path = "/sb/v4/ads/video"
        self.data = data
        return self.execute()

    def create_brand_video_ads(self, data):
        self.method = "post"
        self.uri_path = "/sb/v4/ads/brandVideo"
        self.data = data
        return self.execute()

    def create_store_spotlight_ads(self, data):
        self.method = "post"
        self.uri_path = "/sb/v4/ads/storeSpotlight"
        self.data = data
        return self.execute()



from ..client import Client


class CampaignNegativeKeywords(Client):

    def get_campaign_negative_keywords(self, start_index: int = 0, count: int = 0, match_type_filter: str = None,
                                       keyword_text: str = None, campaign_id_filter: str = None,
                                       keyword_id_filter: str = None):
        self.uri_path = "/v2/sp/campaignNegativeKeywords"
        self.method = "get"
        self.params = {
            "startIndex": start_index,
            "count": count,
            "matchTypeFilter": match_type_filter,
            "keywordText": keyword_text,
            "campaignIdFilter": campaign_id_filter,
            "keywordIdFilter": keyword_id_filter
        }
        return self.execute()

    def create_campaign_negative_keywords(self, data):
        self.uri_path = "/v2/sp/campaignNegativeKeywords"
        self.method = "post"
        self.data = data
        return self.execute()

    def update_campaign_negative_keywords(self, data):
        self.uri_path = "/v2/sp/campaignNegativeKeywords"
        self.method = "put"
        self.data = data
        return self.execute()

    def get_campaign_negative_keywords_extend(self, start_index: int = 0, count: int = 0, match_type_filter: str = None,
                                              keyword_text: str = None, campaign_id_filter: str = None,
                                              keyword_id_filter: str = None):
        self.uri_path = "/v2/sp/campaignNegativeKeywords/extended"
        self.method = "get"
        self.params = {
            "startIndex": start_index,
            "count": count,
            "matchTypeFilter": match_type_filter,
            "keywordText": keyword_text,
            "campaignIdFilter": campaign_id_filter,
            "keywordIdFilter": keyword_id_filter
        }
        return self.execute()

    def get_campaign_negative_keywords_by_id(self, keyword_id):
        self.uri_path = "/v2/sp/campaignNegativeKeywords/{}".format(keyword_id)
        self.method = "get"
        return self.execute()

    def delete_campaign_negative_keywords_by_id(self, keyword_id):
        self.uri_path = "/v2/sp/campaignNegativeKeywords/{}".format(keyword_id)
        self.method = "delete"
        return self.execute()

    def get_campaign_negative_keywords_extend_by_id(self, keyword_id):
        self.uri_path = "/v2/sp/campaignNegativeKeywords/extended/{}".format(keyword_id)
        self.method = "get"
        return self.execute()



from ..client import Client


class ProductAds(Client):

    def get_product_ads_by_id(self, ad_id):
        self.method = "get"
        self.uri_path = "/v2/sp/productAds/{}".format(ad_id)
        return self.execute()

    def delete_product_ads_by_id(self, ad_id):
        self.method = "delete"
        self.uri_path = "/v2/sp/productAds/{}".format(ad_id)
        return self.execute()

    def get_product_ads(self, start_index: int = 0, count: int = None, state_filter: str = None,
                        campaign_id_filter: str = None, ad_group_id_filter: str = None, ad_id_filter: str = None):
        self.method = "get"
        self.uri_path = "/v2/sp/productAds"
        self.params = {
            "startIndex": start_index,
            "count": count,
            "stateFilter": state_filter,
            "campaignIdFilter": campaign_id_filter,
            "adGroupIdFilter": ad_group_id_filter,
            "adIdFilter": ad_id_filter
        }
        return self.execute()

    def create_product_ads(self, params):
        self.method = "post"
        self.uri_path = "/v2/sp/productAds"
        self.data = params
        return self.execute()

    def update_product_ads(self, params):
        self.method = "put"
        self.uri_path = "/v2/sp/productAds"
        self.data = params
        return self.execute()

    def get_product_ads_extended_by_id(self, ad_id):
        self.method = "get"
        self.uri_path = "/v2/sp/productAds/extended/{}".format(ad_id)
        return self.execute()

    def get_product_ads_extended(self, start_index: int = 0, count: int = None, state_filter: str = None,
                                 campaign_id_filter: str = None, ad_group_id_filter: str = None,
                                 ad_id_filter: str = None):
        self.method = "get"
        self.uri_path = "/v2/sp/productAds/extended"
        self.params = {
            "startIndex": start_index,
            "count": count,
            "stateFilter": state_filter,
            "campaignIdFilter": campaign_id_filter,
            "adGroupIdFilter": ad_group_id_filter,
            "adIdFilter": ad_id_filter
        }
        return self.execute()


class ProductAdsV3(Client):

    def create_product_ads(self, data):
        self.method = "post"
        self.uri_path = "/sp/productAds"
        self.data = data
        return self.execute()

    def get_product_ads_list(self, data):
        self.method = "post"
        self.uri_path = "/sp/productAds/list"
        self.data = data
        return self.execute()

    def update_product_ads(self, data):
        self.method = "put"
        self.uri_path = "/sp/productAds"
        self.data = data
        return self.execute()

    def delete_product_ads(self, data):
        self.method = "post"
        self.uri_path = "/sp/productAds/delete"
        self.data = data
        return self.execute()
